@@ -1,4 +1,4 @@
-# Copyright (c) 2021 ING Wholesale Banking Advanced Analytics
+# Copyright (c) 2022 ING Wholesale Banking Advanced Analytics
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy of
 # this software and associated documentation files (the "Software"), to deal in
@@ -72,8 +72,8 @@ def fraction_of_true(bin_labels, bin_entries):
         # convert string to boolean
         bin_labels = np.array([replace(bl) for bl in bin_labels])
 
-    sum_true = np.sum([be for bl, be in zip(bin_labels, bin_entries) if bl == True])
-    sum_false = np.sum([be for bl, be in zip(bin_labels, bin_entries) if bl == False])
+    sum_true = np.sum([be for bl, be in zip(bin_labels, bin_entries) if bl])
+    sum_false = np.sum([be for bl, be in zip(bin_labels, bin_entries) if not bl])
     sum_entries = sum_true + sum_false
     if sum_entries == 0:
         # all nans scenario
@@ -413,8 +413,7 @@ def probability_distribution_mean_covariance(entries_list):
     # Normalize the histograms along the bin axis, so that histograms with different number of entries
     # are still comparable
     normed_list = entries_list / (
-        np.sum(entries_list, axis=1, dtype=np.float)[:, np.newaxis]
-        + np.finfo(np.float).eps
+        np.sum(entries_list, axis=1, dtype=float)[:, np.newaxis] + np.finfo(float).eps
     )
 
     # Determine the mean histogram (unbiased)
